@@ -1,7 +1,6 @@
 import rframe
 
 
-
 import os
 import unittest
 from typing import List
@@ -12,7 +11,7 @@ import tempfile
 
 import pandas as pd
 
-from hypothesis import assume, given, settings
+from hypothesis import HealthCheck, assume, given, settings
 from hypothesis import strategies as st
 from fastapi import FastAPI
 from fastapi.testclient import TestClient
@@ -30,6 +29,7 @@ class TestRest(unittest.TestCase):
     Test the Rest interface
 
     """
+
     def setUp(self):
         db = TinyDB(storage=MemoryStorage)
 
@@ -42,15 +42,15 @@ class TestRest(unittest.TestCase):
 
             self.tables[schema] = table
             router = rframe.SchemaRouter(
-                    schema,
-                    table,
-                    prefix=name,
-                    )
+                schema,
+                table,
+                prefix=name,
+            )
             app.include_router(router)
 
         client = TestClient(app)
         for name, schema in TEST_SCHEMAS.items():
-            source = rframe.RestClient('/'+name, client=client)
+            source = rframe.RestClient("/" + name, client=client)
             self.datasources[schema] = source
 
     @given(SimpleSchema.list_strategy())
@@ -59,7 +59,7 @@ class TestRest(unittest.TestCase):
         self.tables[SimpleSchema].truncate()
         datasource = self.datasources[SimpleSchema]
         SimpleSchema.test(self, datasource, docs)
-       
+
     @given(SimpleMultiIndexSchema.list_strategy())
     @settings(deadline=None)
     def test_simple_multi_index(self, docs: List[SimpleMultiIndexSchema]):
@@ -75,22 +75,22 @@ class TestRest(unittest.TestCase):
         InterpolatingSchema.test(self, datasource, docs)
 
     @given(IntegerIntervalSchema.list_strategy())
-    @settings(deadline=None)
+    @settings(deadline=None, suppress_health_check=[HealthCheck.too_slow])
     def test_integer_interval(self, docs: IntegerIntervalSchema):
         self.tables[IntegerIntervalSchema].truncate()
         datasource = self.datasources[IntegerIntervalSchema]
         IntegerIntervalSchema.test(self, datasource, docs)
 
     @given(TimeIntervalSchema.list_strategy())
-    @settings(deadline=None)
+    @settings(deadline=None, suppress_health_check=[HealthCheck.too_slow])
     def test_time_interval(self, docs: TimeIntervalSchema):
         self.tables[TimeIntervalSchema].truncate()
         datasource = self.datasources[TimeIntervalSchema]
         TimeIntervalSchema.test(self, datasource, docs)
 
     def test_interface_from_url(self):
-        interface = get_interface('http://someserver.com/somepath')
+        interface = get_interface("http://someserver.com/somepath")
         self.assertIsInstance(interface, RestInterface)
 
-        interface = get_interface('https://someserver.com/somepath')
+        interface = get_interface("https://someserver.com/somepath")
         self.assertIsInstance(interface, RestInterface)
